==> routes-0.0.708-beta.tgz: package/src/abi/contracts/IntentSource.ts <==
export const IntentSourceAbi = [
  {
    "inputs": [
      {
        "internalType": "uint256",
        "name": "_minimumDuration",
        "type": "uint256"
      },
      {
        "internalType": "uint256",
        "name": "_counterStart",
        "type": "uint256"
      }
    ],
    "stateMutability": "nonpayable",
    "type": "constructor"
  },
  {
    "inputs": [],
    "name": "CalldataMismatch",
    "type": "error"
  },
  {
    "inputs": [],
    "name": "ExpiryTooSoon",
    "type": "error"
  },
  {
    "inputs": [
      {
        "internalType": "bytes32",
        "name": "_hash",
        "type": "bytes32"
      }
    ],
    "name": "NothingToWithdraw",
    "type": "error"
  },
  {
    "inputs": [],
    "name": "RewardsMismatch",
    "type": "error"
  },
  {
    "inputs": [
      {
        "internalType": "bytes32",
        "name": "_hash",
        "type": "bytes32"
      }
    ],
    "name": "UnauthorizedWithdrawal",
    "type": "error"
  },
  {
    "anonymous": false,
    "inputs": [
      {
        "indexed": true,
        "internalType": "bytes32",
        "name": "_hash",
        "type": "bytes32"
      },
      {
        "indexed": false,
        "internalType": "address",
        "name": "_creator",
        "type": "address"
      },
      {
        "indexed": true,
        "internalType": "uint256",
        "name": "_destinationChain",
        "type": "uint256"
      },
      {
        "indexed": false,
        "internalType": "address[]",
        "name": "_targets",
        "type": "address[]"
      },
      {
        "indexed": false,
        "internalType": "bytes[]",
        "name": "_data",
        "type": "bytes[]"
      },
      {
        "indexed": false,
        "internalType": "address[]",
        "name": "_rewardTokens",
        "type": "address[]"
      },
      {
        "indexed": false,
        "internalType": "uint256[]",
        "name": "_rewardAmounts",
        "type": "uint256[]"
      },
      {
        "indexed": false,
        "internalType": "uint256",
        "name": "_expiryTime",
        "type": "uint256"
      },
      {
        "indexed": false,
        "internalType": "bytes32",
        "name": "nonce",
        "type": "bytes32"
      },
      {
        "indexed": true,
        "internalType": "address",
        "name": "_prover",
        "type": "address"
      }
    ],
    "name": "IntentCreated",
    "type": "event"
  },
  {
    "anonymous": false,
    "inputs": [
      {
        "indexed": false,
        "internalType": "bytes32",
        "name": "_hash",
        "type": "bytes32"
      },
      {
        "indexed": true,
        "internalType": "address",
        "name": "_recipient",
        "type": "address"
      }
    ],
    "name": "Withdrawal",
    "type": "event"
  },
  {
    "inputs": [],
    "name": "CHAIN_ID",
    "outputs": [
      {
        "internalType": "uint256",
        "name": "",
        "type": "uint256"
      }
    ],
    "stateMutability": "view",
    "type": "function"
  },
  {
    "inputs": [],
    "name": "MINIMUM_DURATION",
    "outputs": [
      {
        "internalType": "uint256",
        "name": "",
        "type": "uint256"
      }
    ],
    "stateMutability": "view",
    "type": "function"
  },
  {
    "inputs": [],
    "name": "counter",
    "outputs": [
      {
        "internalType": "uint256",
        "name": "",
        "type": "uint256"
      }
    ],
    "stateMutability": "view",
    "type": "function"
  },
  {
    "inputs": [
      {
        "internalType": "uint256",
        "name": "_destinationChainID",
        "type": "uint256"
      },
      {
        "internalType": "address",
        "name": "_inbox",
        "type": "address"
      },
      {
        "internalType": "address[]",
        "name": "_targets",
        "type": "address[]"
      },
      {
        "internalType": "bytes[]",
        "name": "_data",
        "type": "bytes[]"
      },
      {
        "internalType": "address[]",
        "name": "_rewardTokens",
        "type": "address[]"
      },
      {
        "internalType": "uint256[]",
        "name": "_rewardAmounts",
        "type": "uint256[]"
      },
      {
        "internalType": "uint256",
        "name": "_expiryTime",
        "type": "uint256"
      },
      {
        "internalType": "address",
        "name": "_prover",
        "type": "address"
      }
    ],
    "name": "createIntent",
    "outputs": [],
    "stateMutability": "nonpayable",
    "type": "function"
  },
  {
    "inputs": [
      {
        "internalType": "bytes32",
        "name": "identifier",
        "type": "bytes32"
      }
    ],
    "name": "getIntent",
    "outputs": [
      {
        "components": [
          {
            "internalType": "address",
            "name": "creator",
            "type": "address"
          },
          {
            "internalType": "uint256",
            "name": "destinationChainID",
            "type": "uint256"
          },
          {
            "internalType": "address[]",
            "name": "targets",
            "type": "address[]"
          },
          {
            "internalType": "bytes[]",
            "name": "data",
            "type": "bytes[]"
          },
          {
            "internalType": "address[]",
            "name": "rewardTokens",
            "type": "address[]"
          },
          {
            "internalType": "uint256[]",
            "name": "rewardAmounts",
            "type": "uint256[]"
          },
          {
            "internalType": "uint256",
            "name": "expiryTime",
            "type": "uint256"
          },
          {
            "internalType": "bool",
            "name": "hasBeenWithdrawn",
            "type": "bool"
          },
          {
            "internalType": "bytes32",
            "name": "nonce",
            "type": "bytes32"
          },
          {
            "internalType": "address",
            "name": "prover",
            "type": "address"
          }
        ],
        "internalType": "struct Intent",
        "name": "",
        "type": "tuple"
      }
    ],
    "stateMutability": "view",
    "type": "function"
  },
  {
    "inputs": [
      {
        "internalType": "bytes32",
        "name": "intenthash",
        "type": "bytes32"
      }
    ],
    "name": "intents",
    "outputs": [
      {
        "internalType": "address",
        "name": "creator",
        "type": "address"
      },
      {
        "internalType": "uint256",
        "name": "destinationChainID",
        "type": "uint256"
      },
      {
        "internalType": "uint256",
        "name": "expiryTime",
        "type": "uint256"
      },
      {
        "internalType": "bool",
        "name": "hasBeenWithdrawn",
        "type": "bool"
      },
      {
        "internalType": "bytes32",
        "name": "nonce",
        "type": "bytes32"
      },
      {
        "internalType": "address",
        "name": "prover",
        "type": "address"
      }
    ],
    "stateMutability": "view",
    "type": "function"
  },
  {
    "inputs": [],
    "name": "version",
    "outputs": [
      {
        "internalType": "string",
        "name": "",
        "type": "string"
      }
    ],
    "stateMutability": "pure",
    "type": "function"
  },
  {
    "inputs": [
      {
        "internalType": "bytes32",
        "name": "_hash",
        "type": "bytes32"
      }
    ],
    "name": "withdrawRewards",
    "outputs": [],
    "stateMutability": "nonpayable",
    "type": "function"
  }
] as const

==> routes-0.2.10-beta.tgz: package/src/abi/contracts/IntentSource.ts <==
export const IntentSourceAbi = [
  {
    "inputs": [
      {
        "internalType": "uint256",
        "name": "_counterStart",
        "type": "uint256"
      }
    ],
    "stateMutability": "nonpayable",
    "type": "constructor"
  },
  {
    "inputs": [
      {
        "internalType": "address",
        "name": "target",
        "type": "address"
      }
    ],
    "name": "AddressEmptyCode",
    "type": "error"
  },
  {
    "inputs": [
      {
        "internalType": "address",
        "name": "account",
        "type": "address"
      }
    ],
    "name": "AddressInsufficientBalance",
    "type": "error"
  },
  {
    "inputs": [
      {
        "internalType": "bytes32",
        "name": "_hash",
        "type": "bytes32"
      }
    ],
    "name": "BadClaimant",
    "type": "error"
  },
  {
    "inputs": [],
    "name": "CalldataMismatch",
    "type": "error"
  },
  {
    "inputs": [],
    "name": "FailedInnerCall",
    "type": "error"
  },
  {
    "inputs": [
      {
        "internalType": "bytes32",
        "name": "_hash",
        "type": "bytes32"
      }
    ],
    "name": "NothingToWithdraw",
    "type": "error"
  },
  {
    "inputs": [],
    "name": "RewardsMismatch",
    "type": "error"
  },
  {
    "inputs": [
      {
        "internalType": "address",
        "name": "token",
        "type": "address"
      }
    ],
    "name": "SafeERC20FailedOperation",
    "type": "error"
  },
  {
    "inputs": [
      {
        "internalType": "address",
        "name": "_token",
        "type": "address"
      },
      {
        "internalType": "address",
        "name": "_to",
        "type": "address"
      },
      {
        "internalType": "uint256",
        "name": "_amount",
        "type": "uint256"
      }
    ],
    "name": "TransferFailed",
    "type": "error"
  },
  {
    "inputs": [
      {
        "internalType": "bytes32",
        "name": "_hash",
        "type": "bytes32"
      }
    ],
    "name": "UnauthorizedWithdrawal",
    "type": "error"
  },
  {
    "anonymous": false,
    "inputs": [
      {
        "indexed": true,
        "internalType": "bytes32",
        "name": "_hash",
        "type": "bytes32"
      },
      {
        "indexed": false,
        "internalType": "address",
        "name": "_creator",
        "type": "address"
      },
      {
        "indexed": true,
        "internalType": "uint256",
        "name": "_destinationChain",
        "type": "uint256"
      },
      {
        "indexed": false,
        "internalType": "address[]",
        "name": "_targets",
        "type": "address[]"
      },
      {
        "indexed": false,
        "internalType": "bytes[]",
        "name": "_data",
        "type": "bytes[]"
      },
      {
        "indexed": false,
        "internalType": "address[]",
        "name": "_rewardTokens",
        "type": "address[]"
      },
      {
        "indexed": false,
        "internalType": "uint256[]",
        "name": "_rewardAmounts",
        "type": "uint256[]"
      },
      {
        "indexed": false,
        "internalType": "uint256",
        "name": "_expiryTime",
        "type": "uint256"
      },
      {
        "indexed": false,
        "internalType": "bytes32",
        "name": "nonce",
        "type": "bytes32"
      },
      {
        "indexed": true,
        "internalType": "address",
        "name": "_prover",
        "type": "address"
      },
      {
        "indexed": false,
        "internalType": "uint256",
        "name": "_rewardNative",
        "type": "uint256"
      }
    ],
    "name": "IntentCreated",
    "type": "event"
  },
  {
    "anonymous": false,
    "inputs": [
      {
        "indexed": false,
        "internalType": "bytes32",
        "name": "_hash",
        "type": "bytes32"
      },
      {
        "indexed": true,
        "internalType": "address",
        "name": "_recipient",
        "type": "address"
      }
    ],
    "name": "Withdrawal",
    "type": "event"
  },
  {
    "inputs": [
      {
        "internalType": "bytes32[]",
        "name": "_hashes",
        "type": "bytes32[]"
      },
      {
        "internalType": "address",
        "name": "_claimant",
        "type": "address"
      }
    ],
    "name": "batchWithdraw",
    "outputs": [],
    "stateMutability": "nonpayable",
    "type": "function"
  },
  {
    "inputs": [],
    "name": "counter",
    "outputs": [
      {
        "internalType": "uint256",
        "name": "",
        "type": "uint256"
      }
    ],
    "stateMutability": "view",
    "type": "function"
  },
  {
    "inputs": [
      {
        "internalType": "uint256",
        "name": "_destinationChainID",
        "type": "uint256"
      },
      {
        "internalType": "address",
        "name": "_inbox",
        "type": "address"
      },
      {
        "internalType": "address[]",
        "name": "_targets",
        "type": "address[]"
      },
      {
        "internalType": "bytes[]",
        "name": "_data",
        "type": "bytes[]"
      },
      {
        "internalType": "address[]",
        "name": "_rewardTokens",
        "type": "address[]"
      },
      {
        "internalType": "uint256[]",
        "name": "_rewardAmounts",
        "type": "uint256[]"
      },
      {
        "internalType": "uint256",
        "name": "_expiryTime",
        "type": "uint256"
      },
      {
        "internalType": "address",
        "name": "_prover",
        "type": "address"
      }
    ],
    "name": "createIntent",
    "outputs": [
      {
        "internalType": "bytes32",
        "name": "",
        "type": "bytes32"
      }
    ],
    "stateMutability": "payable",
    "type": "function"
  },
  {
    "inputs": [
      {
        "internalType": "bytes32",
        "name": "identifier",
        "type": "bytes32"
      }
    ],
    "name": "getIntent",
    "outputs": [
      {
        "components": [
          {
            "internalType": "address",
            "name": "creator",
            "type": "address"
          },
          {
            "internalType": "uint256",
            "name": "destinationChainID",
            "type": "uint256"
          },
          {
            "internalType": "address[]",
            "name": "targets",
            "type": "address[]"
          },
          {
            "internalType": "bytes[]",
            "name": "data",
            "type": "bytes[]"
          },
          {
            "internalType": "address[]",
            "name": "rewardTokens",
            "type": "address[]"
          },
          {
            "internalType": "uint256[]",
            "name": "rewardAmounts",
            "type": "uint256[]"
          },
          {
            "internalType": "uint256",
            "name": "expiryTime",
            "type": "uint256"
          },
          {
            "internalType": "bool",
            "name": "isActive",
            "type": "bool"
          },
          {
            "internalType": "bytes32",
            "name": "nonce",
            "type": "bytes32"
          },
          {
            "internalType": "address",
            "name": "prover",
            "type": "address"
          },
          {
            "internalType": "uint256",
            "name": "rewardNative",
            "type": "uint256"
          }
        ],
        "internalType": "struct Intent",
        "name": "",
        "type": "tuple"
      }
    ],
    "stateMutability": "view",
    "type": "function"
  },
  {
    "inputs": [
      {
        "internalType": "bytes32",
        "name": "intentHash",
        "type": "bytes32"
      }
    ],
    "name": "intents",
    "outputs": [
      {
        "internalType": "address",
        "name": "creator",
        "type": "address"
      },
      {
        "internalType": "uint256",
        "name": "destinationChainID",
        "type": "uint256"
      },
      {
        "internalType": "uint256",
        "name": "expiryTime",
        "type": "uint256"
      },
      {
        "internalType": "bool",
        "name": "isActive",
        "type": "bool"
      },
      {
        "internalType": "bytes32",
        "name": "nonce",
        "type": "bytes32"
      },
      {
        "internalType": "address",
        "name": "prover",
        "type": "address"
      },
      {
        "internalType": "uint256",
        "name": "rewardNative",
        "type": "uint256"
      }
    ],
    "stateMutability": "view",
    "type": "function"
  },
  {
    "inputs": [],
    "name": "version",
    "outputs": [
      {
        "internalType": "string",
        "name": "",
        "type": "string"
      }
    ],
    "stateMutability": "pure",
    "type": "function"
  },
  {
    "inputs": [
      {
        "internalType": "bytes32",
        "name": "_hash",
        "type": "bytes32"
      }
    ],
    "name": "withdrawRewards",
    "outputs": [],
    "stateMutability": "nonpayable",
    "type": "function"
  }
] as const
